==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Travail</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Vie</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Un jour avant le début</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Rappellez-le moi demain</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Rappelez-le moi plus tard</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minutes plus tard</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 heure plus tard</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 heures plus tard</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Demain</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Rappel de programme</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 à %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Un jour avant le départ</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Fermer</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Rappelez-le moi demain</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Rappelez-le moi plus tard</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Rappel de planification</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 à %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Aujourd&apos;hui</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Demain</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Travail</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Vie</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Un jour avant le début</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Rappellez-le moi demain</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Rappelez-le moi plus tard</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minutes plus tard</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 heure plus tard</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 heures plus tard</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Demain</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Rappel de programme</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 à %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
